package ab.wifisdab;

/**
 * @author Andreas Butti
 * 
 * @license GPL
 */

import android.app.Activity;
import android.content.Context;
import android.content.SharedPreferences;
import android.os.Bundle;
import android.preference.PreferenceManager;
import android.view.Menu;
import android.view.View;
import android.widget.Button;
import android.widget.TextView;
import android.widget.Toast;
import butt.wifisdaccess.WiFiSdAccess;
import butt.wifisdaccess.WiFiSdListener;

public class ConnectActivity extends Activity {

	private WiFiSdListener listener = new WiFiSdListener() {

		@Override
		public void connectionClosed() {
		}

		@Override
		public void newImage(String path) {
		}

		@Override
		public void errorOccured(final Exception ex) {
			runOnUiThread(new Runnable() {
				public void run() {
					String message = ex.getMessage();

					if (ex.getCause() != null) {
						message += " (" + ex.getCause().getMessage() + ")";
					}

					setState(message);

					Button btReconnect = (Button) findViewById(R.id.buttonReconnect);
					btReconnect.setVisibility(View.VISIBLE);
				}
			});

			ex.printStackTrace();
		}

		@Override
		public void connectionEstablished() {
			runOnUiThread(new Runnable() {
				public void run() {
					Context context = getApplicationContext();
					int duration = Toast.LENGTH_SHORT;

					Toast toast = Toast.makeText(context,
							getText(R.string.connect_connected), duration);
					toast.show();

					finish();
				}
			});
		}
	};

	public void setState(String state) {
		TextView text = (TextView) findViewById(R.id.textConnectState);
		text.setText(state);

	}

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_connect);

		getSd().addListener(listener);
		connect();
	}

	private void connect() {
		SharedPreferences prefs = PreferenceManager
				.getDefaultSharedPreferences(this);

		// TODO: default value twice! in xml and here!
		String url = prefs.getString("pref_key_card_ip", "192.168.11.254");
		setState("Connecting to " + url);
		getSd().connect(url);
	}

	@Override
	protected void onDestroy() {
		getSd().removeListener(listener);
		super.onDestroy();
	}

	private WiFiSdAccess getSd() {
		return ((WiFiSdApplication) getApplication()).getSd();
	}

	public void onConnect(View view) {
		connect();
	}

	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		// Inflate the menu; this adds items to the action bar if it is present.
		getMenuInflater().inflate(R.menu.connect, menu);
		return true;
	}

}
