package ab.wifisdab.control;

/**
 * Listener for Image Downloader
 * 
 * @author Andreas Butti
 * @license GPL
 */
public interface ImageDownloaderListener {

	/**
	 * Got a preview
	 * 
	 * @param preview
	 *            bytes, do NOT CHANGE
	 * @param path
	 *            Path on the SD Card
	 */
	public void gotPreview(byte[] preview, String path);

	/**
	 * The download of the files was finished
	 * 
	 * @param path
	 *            The path on the SD Card
	 * @param androidPath
	 *            The local path on the Android device
	 * @param seconds
	 *            Complete seconds
	 * @param bytesPerSeconds
	 *            Speed
	 */
	public void downloadFinished(String path, String androidPath, int seconds, int bytesPerSeconds);

	/**
	 * Fire download state of an image has increased
	 * 
	 * @param path
	 *            The path on the SD Card
	 * @param current
	 *            Downloaded bytes
	 * @param amount
	 *            total bytes
	 */
	public void downloadProgress(String path, int current, int amount);

}
