package butt.wifisdaccess;

import java.io.Closeable;
import java.io.OutputStream;

import butt.wifisdaccess.model.Exif;

/**
 * WiFi SD Access Interface
 * 
 * @author Andreas Butti
 * 
 */
public interface WiFiSdAccess extends Closeable {

	/**
	 * Connects to the SD Card
	 * 
	 * @param url
	 *            the URL to connect to, for Transcend e.g. 192.168.11.254
	 */
	public void connect(String url);

	/**
	 * Sets a Property for Access implementation
	 * 
	 * @param key
	 *            Key
	 * @param value
	 *            Value
	 */
	public void setProperty(String key, String value);

	/**
	 * Gets a Property
	 * 
	 * @param key
	 *            The Property key
	 * @return The value, or <code>null</code> if not found
	 */
	public String getProperty(String key);

	/**
	 * Adds a listener. Listener are called from different thread!
	 * 
	 * @param listener
	 *            The Listener to add
	 */
	public void addListener(WiFiSdListener listener);

	/**
	 * removes a listener
	 */
	public void removeListener(WiFiSdListener listener);

	/**
	 * Loads EXIF information for an Image
	 * 
	 * @param path
	 *            The Image path
	 * @return Exif Information, or <code>null</code> if not supported
	 */
	public Exif getExifFor(String path);

	/**
	 * Downloads the prview image for a path
	 * 
	 * @param path
	 *            The path to the image
	 * @return The bytes received, or <code>null</code> if an error occured
	 */
	public byte[] downloadPreview(String path);

	/**
	 * Downloads a file from SD Card
	 * 
	 * @param path
	 *            The Path to download
	 * @param out
	 *            Output stream to save data
	 * @param listener
	 *            Listener for progress information
	 * @throws WiFiSdException
	 *             If an error occured
	 */
	public void downloadFile(String path, OutputStream out,
			DownloadProgressListener listener) throws WiFiSdException;

}
