package butt.wifisdaccess.base;

import java.util.ArrayList;
import java.util.Properties;

import butt.wifisdaccess.WiFiSdAccess;
import butt.wifisdaccess.WiFiSdListener;

/**
 * WiFi Access Base Class
 * 
 * @author Andreas Butti
 * 
 */
public abstract class WiFiSdAccessBase implements WiFiSdAccess {

	/**
	 * Properties with settings
	 */
	private Properties properties = new Properties();

	/**
	 * Listener for events
	 */
	private ArrayList<WiFiSdListener> listener = new ArrayList<WiFiSdListener>();

	public WiFiSdAccessBase() {
	}

	@Override
	public void setProperty(String key, String value) {
		properties.setProperty(key, value);
	}

	@Override
	public String getProperty(String key) {
		return properties.getProperty(key);
	}

	/**
	 * Connection to the card was closed
	 */
	protected void fireConnectionClosed() {
		for (WiFiSdListener l : this.listener) {
			l.connectionClosed();
		}
	}

	/**
	 * Fires an exception to the main thread
	 * @param ex The error
	 */
	protected void fireError(Exception ex) {
		for (WiFiSdListener l : this.listener) {
			l.errorOccured(ex);
		}
	}
	
	/**
	 * The connection was established
	 */
	protected void fireConnectionEstablished() {
		for (WiFiSdListener l : this.listener) {
			l.connectionEstablished();
		}
	}


	/**
	 * New image was created
	 * 
	 * @param path
	 *            The Path of the image, to download them
	 */
	protected void fireNewImage(String path) {
		for (WiFiSdListener l : this.listener) {
			l.newImage(path);
		}
	}

	@Override
	public void addListener(WiFiSdListener listener) {
		this.listener.add(listener);
	}

	@Override
	public void removeListener(WiFiSdListener listener) {
		this.listener.remove(listener);
	}
}
