package butt.wifisdaccess.util;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.net.HttpURLConnection;
import java.net.URL;

import butt.wifisdaccess.DownloadProgressListener;

/**
 * HTTP helper util
 * 
 * @author Andreas Butti
 * @license GPL
 * 
 */
public final class HttpUtil {
	/**
	 * Util class
	 */
	private HttpUtil() {
	}

	/**
	 * HTTP Request
	 * 
	 * @param url
	 *            URL to read
	 * @return Bytes received
	 * @throws IOException
	 *             if something went wrong
	 */
	public static byte[] getHttpSimple(URL url) throws IOException {
		HttpURLConnection conn = (HttpURLConnection) url.openConnection();
		conn.setRequestMethod("GET");

		ByteArrayOutputStream out = new ByteArrayOutputStream();

		InputStream in = conn.getInputStream();

		byte[] buffer = new byte[1024];
		int count;
		while ((count = in.read(buffer)) > 0) {
			out.write(buffer, 0, count);
		}
		in.close();
		return out.toByteArray();
	}

	/**
	 * Download over HTTP
	 * 
	 * @param url
	 *            URL to read
	 * @param listener
	 *            Listener for progress
	 * @return Bytes received
	 * @throws IOException
	 *             if something went wrong
	 */
	public static void download(URL url, OutputStream out,
			DownloadProgressListener listener) throws IOException {
		HttpURLConnection conn = (HttpURLConnection) url.openConnection();
		conn.setRequestMethod("GET");

		InputStream in = conn.getInputStream();
		int amount = conn.getContentLength();
		int bytes = 0;

		long startTime = System.currentTimeMillis() / 1000;

		byte[] buffer = new byte[1024];
		int count;
		while ((count = in.read(buffer)) > 0) {
			out.write(buffer, 0, count);

			bytes += count;
			listener.progress(bytes, amount);
		}
		
		if(amount > bytes) {
			throw new IOException("Error download file!" + url);
		}
		
		int timeCount = (int)((System.currentTimeMillis()/ 1000) - startTime);
		listener.finished(timeCount, amount / timeCount);
	}
}
