import java.io.FileOutputStream;
import java.io.IOException;
import java.util.logging.ConsoleHandler;
import java.util.logging.Handler;
import java.util.logging.Logger;

import butt.wifisdaccess.DownloadProgressListener;
import butt.wifisdaccess.WiFiSdAccess;
import butt.wifisdaccess.WiFiSdListener;
import butt.wifisdaccess.model.Exif;
import butt.wifisdaccess.transcend.WiFiSdAccessTranscend;

public class TestMain {

	public static void main(String[] args) throws Exception {
		enableLogger();

		final WiFiSdAccess sd = new WiFiSdAccessTranscend();

		sd.addListener(new WiFiSdListener() {

			private int x = 0;

			@Override
			public void connectionClosed() {
				System.out.println("Connection closed");
				System.exit(100);
			}

			@Override
			public void newImage(String path) {
				System.out.println("Got new image: " + path);

				Exif exif = sd.getExifFor(path);
				System.out.println("Exif: " + exif);

				String file = "/tmp/prev-" + x + ".jpg";

				System.out.println("Download preview: " + file);

				try {
					FileOutputStream out = new FileOutputStream(file);
					out.write(sd.downloadPreview(path));
					out.close();
				} catch (IOException e) {
					e.printStackTrace();
				}

				System.out.println("got preview");

				System.out.println("download file");

				try {
					file = "/tmp/full-" + x + ".jpg";
					FileOutputStream out = new FileOutputStream(file);

					try {
						sd.downloadFile(path, out,
								new DownloadProgressListener() {

									@Override
									public void progress(int current, int amount) {
										System.out.println("Progress: "
												+ current + " / " + amount
												+ " "
												+ (100.0 * current / amount)
												+ "%");
									}

									@Override
									public void finished(int seconds,
											int bytesPerSeconds) {

										System.out.println("================");
										System.out
												.println("Download finished: "
														+ seconds + "s, "
														+ bytesPerSeconds
														+ " bytes/s");
									}
								});
					} catch (Exception e) {
						e.printStackTrace();
					}
					out.close();
				} catch (IOException e) {
					e.printStackTrace();
				}

				System.out.println("got file");

				x++;

			}

			@Override
			public void errorOccured(Exception ex) {
				ex.printStackTrace();
				System.exit(101);
			}

			@Override
			public void connectionEstablished() {
				// TODO Auto-generated method stub
				
			}
		});

		System.out.println("Connect");
		sd.connect("192.168.11.254");
		System.out.println("Connected!");

		// 1h, for debugging
		Thread.sleep(3600 * 1000);

		System.out.println("Close connection");
		sd.close();
	}

	private static void enableLogger() {
		// get the top Logger:
		Logger topLogger = java.util.logging.Logger.getLogger("");

		// Handler for console (reuse it if it already exists)
		Handler consoleHandler = null;
		// see if there is already a console handler
		for (Handler handler : topLogger.getHandlers()) {
			if (handler instanceof ConsoleHandler) {
				// found the console handler
				consoleHandler = handler;
				break;
			}
		}

		if (consoleHandler == null) {
			// there was no console handler found, create a new one
			consoleHandler = new ConsoleHandler();
			topLogger.addHandler(consoleHandler);
		}
		// set the console handler to fine:
		consoleHandler.setLevel(java.util.logging.Level.FINEST);
	}
}
